## Plain text

Here is some plain text.

Now we add a citation: a Langtangen book #[1]. And a paper [2].

## Explanation

Let's explain some of this code (setting the code to be unexecutable):

The `for` loop:

    for number in range(10):
       total = total + (number + 1)

    ---------------------------------------------------------------------------
    NameError                                 Traceback (most recent call last)
     in
          1 for number in range(10):
    ----> 2    total = total + (number + 1)

    NameError: name 'total' is not defined

Goes through numbers 0 to 9 and adds 1 more than each number to the `total` variable.

## Table

The data on exponential growth can be found in the table below.

time | count
--- | ---
60 | 10000
90 | 25587
120 | 76327
150 | 212715
180 | 619511
210 | 1940838
240 | 4240760
270 | 13993730
300 | 38971086
330 | 105614040

## Figure

See figure PythonDict for an illustration that explains the python dictionary concept.

## Math

Now we add some mathematical formula:

$$ \begin{equation*} K_n = rwTK_{n-1}\left (1 - \frac{K_{n-1}}{H}\right ) - K_{n-1}. \end{equation*} $$

## References